from setuptools import setup, find_packages

setup(
    name='lEmoji',
    version='0.1 beta',
    keywords=('emoji',),
    description='emoji list for all version based on unicode.org',
    license='MIT Licence',
    url='https://github.com/lqj679ssn/emoji',
    author='Jyonn Liu',
    author_email='i@6-79.cn',
    platforms='any',
    packages=find_packages(),
    install_requires=[],
)
